/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit;

import java.io.Serializable;


/**
 * Class representing the status of a test context.
 *
 * @author    Simon Brown
 */
public abstract class TestContextStatus implements Serializable {

  private String name;

  /**
   * Creates a new TestContextStatus - private so no other instances
   * can be created.
   */
  public TestContextStatus(String name) {
    this.name = name;
  }

  /**
   * Gets the name of this status.
   *
   * @return    the name as a String
   */
  public String getName() {
    return name;
  }

  public abstract boolean getResult();

  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }

    if (!(o instanceof TestContextStatus)) {
      return false;
    }

    TestContextStatus testContextStatus = (TestContextStatus)o;
    return (testContextStatus.getName().equals(name));
  }

  public int hashCode() {
    return (name != null ? name.hashCode() : 0);
  }

  public String toString() {
    return name;
  }

}

class NegativeTestContextStatus extends TestContextStatus {

  public NegativeTestContextStatus(String name) {
    super(name);
  }

  public boolean getResult() {
    return false;
  }

}

class PositiveTestContextStatus extends TestContextStatus {

  public PositiveTestContextStatus(String name) {
    super(name);
  }

  public boolean getResult() {
    return true;
  }

}