/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.tagext.assertion;

import org.tagunit.TestContextContainer;
import org.tagunit.test.ExceptionTestPackage;
import org.tagunit.test.TestPackage;

/**
 * Asserts that its body content throws a named exception.
 *
 * @author    Simon Brown
 */
public class AssertExceptionTag extends AssertTag {

  /** the fully qualified name of the exception */
  private String exception;

  /** the error message */
  private String message;

  /**
   * Template method called during doEndTag(). Tags can override this to
   * perform any custom processing.
   *
   * @param testContext   the current test context container
   */
  protected void doEndTag(TestContextContainer testContext) {
    // do nothing - this is a special case
  }

  /**
   * Thrown after the invocation of the tag.
   */
  public final void doFinally() {
    executeTestPackage();
    super.doFinally();
  }

  /**
   * Setter for the exception name.
   *
   * @param s   the name of the exception
   */
  public void setException(String s) {
    this.exception = s;
  }

  /**
   * Setter for the message.
   *
   * @param s   the message
   */
  public void setMessage(String s) {
    this.message = s;
  }

  /**
   * Gets the test package containing the actual tests and assertions.
   *
   * @return  a TestPackage instance
   */
  protected TestPackage getTestPackage() {
    if (exception == null) {
      return new ExceptionTestPackage();
    } else if (message == null) {
      return new ExceptionTestPackage(exception);
    } else {
      return new ExceptionTestPackage(exception, message);
    }
  }

}