/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.tagext.assertion;

import org.tagunit.test.PageContextAttributeTestPackage;
import org.tagunit.test.TestPackage;

/**
 *
 * @author    Simon Brown
 */
public class AssertPageContextAttributeTag extends AssertTag {

  /** the property (of a JavaBean) to be tested */
  private String property;

  /** the type (class name) of the attribute to be tested */
  private String type;

  /** the value of the attribute to be tested */
  private Object value;

  /** the scope of the attribute to be tested */
  private String scope;

  /**
   * Gets the test package containing the actual tests and assertions.
   *
   * @return  a TestPackage instance
   */
  protected TestPackage getTestPackage() {
    return new PageContextAttributeTestPackage(getName(), property, type, value, scope);
  }

  /**
   * Setter for the type attrbute.
   *
   * @param s   a String representing the fully qualified class name
   */
  public void setType(String s) {
    this.type = s;
  }

  /**
   * Setter for the value attrbute.
   *
   * @param o   an Object representing the value to be tested against
   */
  public void setValue(Object o) {
    this.value = o;
  }

  /**
   * Setter for the scope attrbute.
   *
   * @param s   a String representing the scope
   *            (request, page, session or application)
   */
  public void setScope(String s) {
    this.scope = s;
  }

  /**
   * Setter for the property attrbute.
   *
   * @param s   a String representing the property
   */
  public void setProperty(String s) {
    this.property = s;
  }

}