/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.tagext.assertion;

import org.tagunit.TestContextContainer;
import org.tagunit.TestContext;
import org.tagunit.tagext.test.TestContextTag;
import org.tagunit.test.TestPackage;
import org.tagunit.util.ExceptionUtils;

/**
 * Superclass for all assertion tags.
 *
 * @author    Simon Brown
 */
abstract class AssertTag extends TestContextTag {

  /**
   * Template method called during doEndTag(). Tags can override this to
   * perform any custom processing.
   *
   * @param testContext   the current test context container
   */
  protected void doEndTag(TestContextContainer testContext) {
    executeTestPackage();
    super.doEndTag(testContext);
  }

  /**
   * Runs the test package associated with this assertion tag.
   */
  protected void executeTestPackage() {
    try {
      // create the test package that contains the tests for this particular
      // assertion or test
      TestPackage testPackage = getTestPackage();
      testPackage.setName(getName());
      testPackage.setPageContext(pageContext);
      testPackage.setThrowable(getThrowable());
      getTestContext().setName(testPackage.getName());

      // and finally, run the test package (provided that the
      // test hasn't already failed for some reason)
      testPackage.executeTest(getTestContext());
    } catch (Exception e) {
      getTestContext().setStatus(TestContext.ERROR);
      getTestContext().setMessage(ExceptionUtils.getStackTraceAsString(e));
    }
  }

  /**
   * Gets the test package containing the actual tests and assertions.
   *
   * @return  a TestPackage instance
   */
  protected abstract TestPackage getTestPackage() throws Exception;

}