/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.tagext.display;

import java.util.Collection;
import java.util.Iterator;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;

import org.tagunit.*;

/**
 * A custom tag that helps to generate a menu from a Menu instance.
 *
 * @author    Simon Brown
 */
public class ShowTestResultsTag extends TagSupport implements TestContextProvider {

  /** a flag inidicating whether automatically generated tests should be shown */
  private boolean showAutomaticTests = false;

  /** the name of the menu to be shown */
  private String name;

  /** the iterator used by this tag */
  private Iterator iterator;

  /** the current TestContext */
  private TestContext currentTestContext;

  /** the current level in the tree */
  private int currentLevel = 0;

  /**
   * Called when the starting tag is encountered.
   */
  public int doStartTag() throws JspException {
    iterator = ((Collection)pageContext.getRequest().getAttribute(Constants.TEST_RESULTS)).iterator();

    if (iterator.hasNext()) {
      TestResult result = (TestResult)iterator.next();

      // store the current state so that it can be used by child tags
      this.currentTestContext = result.getTestContext();
      this.currentLevel = result.getLevel();

      pageContext.setAttribute(getId(), currentTestContext);
      pageContext.setAttribute("level", new Integer(currentLevel));

      // and include the body
      return EVAL_BODY_INCLUDE;
    } else {
      // there are no menu items so skip the body
      return SKIP_BODY;
    }
  }

  /**
   * Called after the body has been evaluated.
   */
  public int doAfterBody() throws JspException {
    if (iterator.hasNext()) {
      TestResult result = (TestResult)iterator.next();

      // store the current state so that it can be used by child tags
      this.currentTestContext = result.getTestContext();
      this.currentLevel = result.getLevel();

      pageContext.setAttribute(getId(), currentTestContext);
      pageContext.setAttribute("level", new Integer(currentLevel));

      // and instruct the JSP engine to re-evaluate the body of this tag
      return EVAL_BODY_AGAIN;
    } else {
      // there are no more menu items so skip the body
      return SKIP_BODY;
    }
  }

  /**
   * Gets a reference to the current TestContext - be it a Menu or a MenuItem.
   *
   * @return  a TestContext instance
   */
  public TestContext getCurrentTestContext() {
    return this.currentTestContext;
  }

  /**
   * Gets a reference to the current TestContext - be it a Menu or a MenuItem.
   *
   * @return  a TestContext instance
   */
  public TestContext getTestContext() {
    return this.currentTestContext;
  }

  /**
   * Gets the level of the current TestContext in the tree.
   *
   * @return  an integer representing the level
   */
  public int getCurrentLevel() {
    return currentLevel;
  }

}