/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.tagext.test;

import org.tagunit.TagLibraryTestContext;
import org.tagunit.TestContextContainer;
import org.tagunit.Constants;
import org.tagunit.test.TagLibraryTestPackage;

import javax.servlet.jsp.PageContext;

/**
 * Represents the top level test tag used for testing a tag library.
 *
 * @author    Simon Brown
 */
public class TagLibraryTestContextTag extends TestContextTag {

  /** the base uri from the which tests for the tags can be found */
  private String uri;

  /**
   * Creates the test context container for this tag.
   *
   * @return    a TestContextContainer instance
   */
  protected TestContextContainer createTestContext() {
    return new TagLibraryTestContext("Tag library test context");
  }

  /**
   * Template method called during doEndTag(). Tags can override this to
   * perform any custom processing.
   *
   * @param testContext   the current test context container
   */
  protected void doEndTag(TestContextContainer testContext) {
    TagLibraryTestContext tltc = (TagLibraryTestContext)testContext;

    String tag = (String)pageContext.getAttribute(Constants.TAG_TO_BE_TESTED, PageContext.REQUEST_SCOPE);

    // only execute the tag tests if the TLD file was located
    if (tltc.getTagLibraryInfo() != null) {
      TagLibraryTestPackage tests = new TagLibraryTestPackage(tltc.getTagLibraryInfo(), getBaseUri(), tag, pageContext);
      tests.executeTest(tltc);
    }
  }

  /**
   * Setter for the uri property.
   *
   * @param uri       the URI as a String
   */
  public void setUri(String uri) {
    this.uri = uri;
  }

  /**
   * Calculates the base URI for the tests.
   *
   * @return  the starting URI with an ending '/' character
   */
  private String getBaseUri() {
    String baseUri;
    if (!uri.endsWith("/")) {
      baseUri = uri + "/";
    } else {
      baseUri = uri;
    }
    return baseUri;
  }

}