/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.taginfo;

import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * A parser that turns an XML document into an in-memory representation of
 * the tag library descriptor.
 *
 * @author    Simon Brown
 */
public abstract class TagLibraryDescriptorParser {

  /**
   * Parses the supplied Document representing a TLD file.
   *
   * @param doc   an XML Document object
   * @return  a TagLibraryInfo object representing the TLD
   * @throws org.tagunit.taginfo.TagLibraryInfoParseException  if the Document can't be parsed
   */
  public abstract TagLibraryInfo parse(Document doc) throws TagLibraryInfoParseException;

  /**
   * Helper method to get the (text) value from a node.
   *
   * @param node    an XML node
   * @return  the text value of that node (the value of it's child)
   */
  protected String getNodeValue(Node node) {
    if (node == null || node.getFirstChild() == null) {
      return null;
    } else {
      String s = node.getFirstChild().getNodeValue();
      if (s != null) {
        return s.trim();
      } else {
        return s;
      }
    }
  }

}
