/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.test;

import javax.servlet.http.HttpServletResponse;

import org.tagunit.TestContextContainer;
import org.tagunit.TestContext;

/**
 * Asserts that a named header exists, and optionally also asserts its value.
 *
 * @author    Simon Brown
 */
public class HeaderTestPackage extends AbstractTestPackage {

  private String name;
  private String value;

  /**
   * Creates a new test package for the specified tag.
   */
  public HeaderTestPackage(String name, String value) {
    this.name = name;
    this.value = value;
  }

  /**
   * Runs the tests that are part of this test package.
   *
   * @param testContext   the TestContext to which these tests are to be run
   */
  public void executeTest(TestContextContainer testContext) {
    HttpServletResponse response = (HttpServletResponse)getPageContext().getResponse();
    boolean b = response.containsHeader(name);

    if (!b) {
      testContext.setMessage("Header named " + name + " does not exist.");
      testContext.setStatus(TestContext.FAIL);
    }
  }

  /**
   * Gets the name of this test package.
   *
   * @return  the name of this test package as a String
   */
  public String getName() {
    if (value == null) {
      return "Existence of header named " + name;
    } else {
      return "Existence of header named " + name + " (value=" + value + ")";
    }
  }

}