/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.test;

import junit.framework.TestCase;
import org.tagunit.DefaultTestContextContainer;
import org.tagunit.taginfo.TagAttributeInfo;
import org.tagunit.taginfo.TagInfo;

/**
 * Test cases for the AttributeTestPackage class.
 *
 * @author      Simon Brown
 */
public class AttributeTestPackageTest extends TestCase {

  private TagInfo tagInfo;

  public void setUp() {
    tagInfo = new TagInfo();
  }

  /**
   * Tests that an attribute exists.
   */
  public void testAttributeExists() {
    AttributeTestPackage testPackage = new AttributeTestPackage(tagInfo, "name", "java.lang.String", false, false);
    DefaultTestContextContainer context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    TagAttributeInfo attr = new TagAttributeInfo();
    attr.setName("name");
    attr.setType("java.lang.String");
    attr.setRequired(false);
    attr.setAcceptRequestTimeExpressions(false);
    tagInfo.add(attr);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());
  }

  /**
   * Tests the type of an attribute.
   */
  public void testAttributeType() {
    TagAttributeInfo attr = new TagAttributeInfo();
    attr.setName("name");
    attr.setType("java.lang.String");
    attr.setRequired(false);
    attr.setAcceptRequestTimeExpressions(false);
    tagInfo.add(attr);

    AttributeTestPackage testPackage = new AttributeTestPackage(tagInfo, "name", "java.lang.String", false, false);
    DefaultTestContextContainer context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    testPackage = new AttributeTestPackage(tagInfo, "name", "java.lang.Integer", false, false);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());
  }

  /**
   * Tests whether an attribute is required or not.
   */
  public void testAttributeIsRequired() {
    TagAttributeInfo attr = new TagAttributeInfo();
    attr.setName("name");
    attr.setType("java.lang.String");
    attr.setRequired(true);
    attr.setAcceptRequestTimeExpressions(false);
    tagInfo.add(attr);

    AttributeTestPackage testPackage = new AttributeTestPackage(tagInfo, "name", "java.lang.String", true, false);
    DefaultTestContextContainer context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    testPackage = new AttributeTestPackage(tagInfo, "name", "java.lang.String", false, false);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());
  }

  /**
   * Tests whether an attribute accepts request-time expressions or not.
   */
  public void testAttributeAcceptsRequestTimeExpressions() {
    TagAttributeInfo attr = new TagAttributeInfo();
    attr.setName("name");
    attr.setType("java.lang.String");
    attr.setRequired(false);
    attr.setAcceptRequestTimeExpressions(true);
    tagInfo.add(attr);

    AttributeTestPackage testPackage = new AttributeTestPackage(tagInfo, "name", "java.lang.String", false, true);
    DefaultTestContextContainer context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    testPackage = new AttributeTestPackage(tagInfo, "name", "java.lang.String", false, false);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());
  }

}